<a id="widgets.line_widgets.*"></a>

## \*

<a id="widgets.line_widgets.VLine"></a>

## VLine Objects

```python
class VLine(QFrame)
```

<a id="widgets.line_widgets.VLine.__init__"></a>

#### \_\_init\_\_

```python
def __init__(parent=None, line_width=1)
```

<a id="widgets.line_widgets.HLine"></a>

## HLine Objects

```python
class HLine(QFrame)
```

<a id="widgets.line_widgets.HLine.__init__"></a>

#### \_\_init\_\_

```python
def __init__(parent=None, line_width=1)
```

